==> ejc-report-impl-3.0.1-20240703.080938-192-sources.jar: com/ejianc/foundation/report/util/ExcelExportUtil.java <==
package com.ejianc.foundation.report.util;

import java.io.IOException;
import java.io.OutputStream;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.hssf.util.HSSFColor;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.poi.xssf.usermodel.XSSFCellStyle;
import org.apache.poi.xssf.usermodel.XSSFFont;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.alibaba.fastjson.JSONObject;
import com.google.common.base.Strings;

public class ExcelExportUtil {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    //表头
    private String title;
    //各个列的表头
    private String[] heardList;
    private Map<String, String> headerMap = new HashMap<>();
    //各个列的元素key值
    private String[] heardKey;
    //需要填充的数据信息
    private List<JSONObject> data;
    //字体大小
    private int fontSize = 14;
    //行高
    private int rowHeight = 30;
    //列宽
    private int columWidth = 200;
    //工作表
    private String sheetName = "sheet1";

    private List<String> fieldFormat;

    private SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");
    private SimpleDateFormat dateTimeFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    private DecimalFormat decimalFormat = new DecimalFormat("###,##0.00");
    private final static Integer SHEET_DATA_SIZE = 300;

    //字段格式化
    public List<String> getFieldFormat() {
        return fieldFormat;
    }

    public void setFieldFormat(List<String> fieldFormat) {
        this.fieldFormat = fieldFormat;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String[] getHeardList() {
        return heardList;
    }

    public void setHeardList(String[] heardList) {
        this.heardList = heardList;
    }

    public String[] getHeardKey() {
        return heardKey;
    }

    public void setHeardKey(String[] heardKey) {
        this.heardKey = heardKey;
    }

    public List<JSONObject> getData() {
        return data;
    }

    public void setData(List<JSONObject> data) {
        this.data = data;
    }

    public int getFontSize() {
        return fontSize;
    }

    public void setFontSize(int fontSize) {
        this.fontSize = fontSize;
    }

    public int getRowHeight() {
        return rowHeight;
    }

    public void setRowHeight(int rowHeight) {
        this.rowHeight = rowHeight;
    }

    public int getColumWidth() {
        return columWidth;
    }

    public void setColumWidth(int columWidth) {
        this.columWidth = columWidth;
    }

    public String getSheetName() {
        return sheetName;
    }

    public void setSheetName(String sheetName) {
        this.sheetName = sheetName;
    }

    public Map<String, String> getHeaderMap() {
        return headerMap;
    }

    public void setHeaderMap(Map<String, String> headerMap) {
        this.headerMap = headerMap;
    }

    /**
     * 开始导出数据信息
     *
     */
    public void exportExport(HttpServletRequest request, HttpServletResponse response) throws IOException {
        //检查参数配置信息
        checkConfig();
        //创建工作簿
        @SuppressWarnings("resource")
        XSSFWorkbook wb = new XSSFWorkbook();
        Integer dataSize = data.size();
        Long sheetNum = dataSize / SHEET_DATA_SIZE  +  (dataSize % SHEET_DATA_SIZE == 0 ? 0L : 1L);
    	for(int num=0;num<sheetNum;num++) {
    		int fromIndex = num*SHEET_DATA_SIZE;
    		int toIndex = Math.min(fromIndex + SHEET_DATA_SIZE, data.size());
    		List<JSONObject> exportDataList = data.subList(fromIndex, toIndex);
    		
    		//创建工作表
            XSSFSheet wbSheet = wb.createSheet(this.sheetName+num+1);
            //设置默认行宽
            wbSheet.setDefaultColumnWidth(20);

            // 标题样式（加粗，垂直居中）
            XSSFCellStyle cellStyle = wb.createCellStyle();
            cellStyle.setAlignment(HSSFCellStyle.ALIGN_CENTER);//水平居中
            cellStyle.setVerticalAlignment(HSSFCellStyle.VERTICAL_CENTER);//垂直居中
            XSSFFont fontStyle = wb.createFont();
            fontStyle.setBoldweight(HSSFFont.BOLDWEIGHT_BOLD);
            fontStyle.setBold(true);   //加粗
            fontStyle.setFontHeightInPoints((short)16);  //设置标题字体大小
            cellStyle.setFont(fontStyle);
            setBorderStyle(cellStyle); //设置边框

            //在第0行创建rows  (表标题)
            XSSFRow title = wbSheet.createRow((int) 0);
            title.setHeightInPoints(30);//行高
            XSSFCell cellValue = title.createCell(0);
            cellValue.setCellValue(this.title);
            cellValue.setCellStyle(cellStyle);
            wbSheet.addMergedRegion(new CellRangeAddress(0,0,0,(this.heardList.length-1)));


            //在第1行创建rows
            XSSFRow row = wbSheet.createRow((int) 1);
            //设置列头元素
            XSSFCell cellHead = null;
            XSSFCellStyle firstRowStyle = getCommonCellStyle(wb);
            for (int i = 0; i < heardList.length; i++) {
                cellHead = row.createCell(i);
                cellHead.setCellValue(heardList[i]);
                cellHead.setCellStyle(firstRowStyle);
            }

            //设置每格数据的样式 （字体红色）
            XSSFCellStyle cellParamStyle = wb.createCellStyle();
            XSSFFont ParamFontStyle = wb.createFont();
            cellParamStyle.setAlignment(HSSFCellStyle.ALIGN_CENTER);
            cellParamStyle.setVerticalAlignment(HSSFCellStyle.VERTICAL_CENTER);
            ParamFontStyle.setColor(HSSFColor.DARK_RED.index);   //设置字体颜色 (红色)
            ParamFontStyle.setFontHeightInPoints((short) this.fontSize);
            cellParamStyle.setFont(ParamFontStyle);
            //设置每格数据的样式2（字体蓝色）
            XSSFCellStyle cellParamStyle2 = wb.createCellStyle();
            cellParamStyle2.setAlignment(HSSFCellStyle.ALIGN_CENTER);
            cellParamStyle2.setVerticalAlignment(HSSFCellStyle.VERTICAL_CENTER);
            XSSFFont ParamFontStyle2 = wb.createFont();
            ParamFontStyle2.setColor(HSSFColor.BLUE.index);   //设置字体颜色 (蓝色)
            ParamFontStyle2.setFontHeightInPoints((short) this.fontSize);
            cellParamStyle2.setFont(ParamFontStyle2);
            //开始写入实体数据信息
            int a = 2;
            for (int i = 0; i < exportDataList.size(); i++) {
                XSSFRow roww = wbSheet.createRow((int) a);
                JSONObject map = exportDataList.get(i);
                XSSFCell cell = null;
                for (int j = 0; j < heardKey.length; j++) {
                    cell = roww.createCell(j);
                    cell.setCellStyle(getCommonCellStyle(wb));
                    cell.getCellStyle().setAlignment(getCellAlignType(headerMap.get(heardKey[j] + "AlignType"))); //重新设置对齐方式
                    Object valueObject = map.get(heardKey[j]);
                    String value = null;
                    if (valueObject == null) {
                        valueObject = "";
                    }

                    if (valueObject instanceof String) {
                        //取出的数据是字符串直接赋值
                        value = (String) map.get(heardKey[j]);
                    } else if (valueObject instanceof Integer) {
                        //取出的数据是Integer
                        value = String.valueOf(((Integer) (valueObject)).floatValue());
                    } else if (valueObject instanceof Number) {
                        value = new BigDecimal(valueObject.toString()).toPlainString();
                    } else {
                        value = valueObject.toString();
                    }
                    value = formatField(value, fieldFormat.get(j));
                    //设置单个单元格的字体颜色
                    if(heardKey[j].equals("ddNum") || heardKey[j].equals("sjNum")){
                        if((Long)map.get("ddNum")!=null){
                            if((Long)map.get("sjNum")==null){
                                cell.setCellStyle(cellParamStyle);
                            } else if((Long) map.get("ddNum") != (Long) map.get("sjNum")){
                                if ((Long) map.get("ddNum") > (Long) map.get("sjNum")) {
                                    cell.setCellStyle(cellParamStyle);
                                }
                                if ((Long) map.get("ddNum") < (Long) map.get("sjNum")) {
                                    cell.setCellStyle(cellParamStyle2);
                                }
                            }else {
                                cell.setCellStyle(getCommonCellStyle(wb));
                            }
                        }
                    }
                    if (valueObject instanceof Number) {
                        if(StringUtils.isNotEmpty(value)){
                            XSSFCellStyle style = getCommonCellStyle(wb);
                            if (valueObject instanceof Integer) {
                                cell.setCellValue((Integer)valueObject);
                                style.setDataFormat(wb.createDataFormat().getFormat("0"));
                            }else {
                                String valueStr = value.replaceAll(",", ""); // 删除逗号
                                if(StringUtils.isEmpty(value)){
                                    valueStr = "0.00";
                                }
                                cell.setCellValue(new Double(valueStr));
                                style.setDataFormat(wb.createDataFormat().getFormat("0.00"));
                            }
                            if(StringUtils.isNotEmpty(fieldFormat.get(j))){
                                switch (fieldFormat.get(j)) {
                                    case "twoDecimalNumbers":
                                    case "mnyFormat":
                                        style.setDataFormat(wb.createDataFormat().getFormat("0.00"));
                                        break;
                                    case "integer":
                                        style.setDataFormat(wb.createDataFormat().getFormat("0"));
                                        break;
                                    default:
                                }
                            }
                            cell.setCellStyle(style);
                        }
                    }else {
                        cell.setCellValue(Strings.isNullOrEmpty(value) ? "" : value);
                    }
                }
                a++;
            }
    	}
        //导出数据
        try {
            //设置Http响应头告诉浏览器下载这个附件
            response.setHeader("Content-Disposition", "attachment;Filename=" + System.currentTimeMillis() + ".xlsx"); 
            OutputStream outputStream = response.getOutputStream();
            wb.write(outputStream);
            outputStream.close();
        } catch (Exception ex) {
            ex.printStackTrace();
            throw new IOException("导出Excel出现严重异常，异常信息：" + ex.getMessage());
        }
    }

    private void setBorderStyle(XSSFCellStyle cellStyle) {
        cellStyle.setBorderBottom(XSSFCellStyle.BORDER_THIN); //下边框
        cellStyle.setBorderLeft(XSSFCellStyle.BORDER_THIN);//左边框
        cellStyle.setBorderTop(XSSFCellStyle.BORDER_THIN);//上边框
        cellStyle.setBorderRight(XSSFCellStyle.BORDER_THIN);//右边框
    }

    private String formatField(String value, String format) {
        String result = null;

        if(StringUtils.isBlank(value) || StringUtils.isBlank(format)) {
            return value;
        }
        try {
            switch (format) {
                case "twoDecimalNumbers":
                    result = new BigDecimal(value).setScale(2, BigDecimal.ROUND_HALF_UP).toString();
                    break;
                case "integer":
                    result = new BigDecimal(value).setScale(0, BigDecimal.ROUND_HALF_UP).toString();
                    break;
                case "mnyFormat":
                    result = decimalFormat.format( new BigDecimal(value).setScale(6, BigDecimal.ROUND_HALF_UP));
                    break;
                case "yyyy-MM-dd":
                    result = dateFormat.format(dateFormat.parse(value));
                    break;
                case "yyyy-MM-dd HH:mm:ss":
                    result = dateTimeFormat.format(dateTimeFormat.parse(value));
                    break;
                default:
            }
        } catch (Exception e) {
            logger.error("依据模式[{}],格式化格式化[{}]异常：", format, value, e);
            return value;
        }
        return result;
    }


    /**
     * 检查数据配置问题
     *
     * @throws IOException 抛出数据异常类
     */
    protected void checkConfig() throws IOException {
        if (heardKey == null || heardList.length == 0) {
            throw new IOException("列名数组不能为空或者为NULL");
        }

        if (fontSize < 0 || rowHeight < 0 || columWidth < 0) {
            throw new IOException("字体、宽度或者高度不能为负值");
        }

        if (Strings.isNullOrEmpty(sheetName)) {
            throw new IOException("工作表表名不能为NULL");
        }
    }

    private XSSFCellStyle getCommonCellStyle(XSSFWorkbook wb) {
        //设置表头样式，表头居中
        XSSFCellStyle style = wb.createCellStyle();
        //设置单元格样式
        style.setAlignment(HSSFCellStyle.ALIGN_CENTER);
        style.setVerticalAlignment(HSSFCellStyle.VERTICAL_CENTER);
        //设置字体
        XSSFFont font = wb.createFont();
        font.setFontHeightInPoints((short) this.fontSize);
        style.setFont(font);
        setBorderStyle(style); //设置边框

        return style;
    }

    private short getCellAlignType(String columnAlignType) {
        short alignType = HSSFCellStyle.ALIGN_CENTER;
        switch (columnAlignType) {
            case "left":
                alignType = HSSFCellStyle.ALIGN_LEFT;
                break;
            case "center":
                alignType = HSSFCellStyle.ALIGN_CENTER;
                break;
            case "right":
                alignType = HSSFCellStyle.ALIGN_RIGHT;
                break;
        }
        return alignType;
    }
}

==> ejc-report-impl-3.0.1-20240703.082359-193-sources.jar: com/ejianc/foundation/report/util/ExcelExportUtil.java <==
package com.ejianc.foundation.report.util;

import java.io.IOException;
import java.io.OutputStream;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.hssf.util.HSSFColor;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.poi.xssf.usermodel.XSSFCellStyle;
import org.apache.poi.xssf.usermodel.XSSFFont;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.alibaba.fastjson.JSONObject;
import com.google.common.base.Strings;

public class ExcelExportUtil {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    //表头
    private String title;
    //各个列的表头
    private String[] heardList;
    private Map<String, String> headerMap = new HashMap<>();
    //各个列的元素key值
    private String[] heardKey;
    //需要填充的数据信息
    private List<JSONObject> data;
    //字体大小
    private int fontSize = 14;
    //行高
    private int rowHeight = 30;
    //列宽
    private int columWidth = 200;
    //工作表
    private String sheetName = "sheet";

    private List<String> fieldFormat;

    private SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");
    private SimpleDateFormat dateTimeFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    private DecimalFormat decimalFormat = new DecimalFormat("###,##0.00");
    private final static Integer SHEET_DATA_SIZE = 1000;

    //字段格式化
    public List<String> getFieldFormat() {
        return fieldFormat;
    }

    public void setFieldFormat(List<String> fieldFormat) {
        this.fieldFormat = fieldFormat;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String[] getHeardList() {
        return heardList;
    }

    public void setHeardList(String[] heardList) {
        this.heardList = heardList;
    }

    public String[] getHeardKey() {
        return heardKey;
    }

    public void setHeardKey(String[] heardKey) {
        this.heardKey = heardKey;
    }

    public List<JSONObject> getData() {
        return data;
    }

    public void setData(List<JSONObject> data) {
        this.data = data;
    }

    public int getFontSize() {
        return fontSize;
    }

    public void setFontSize(int fontSize) {
        this.fontSize = fontSize;
    }

    public int getRowHeight() {
        return rowHeight;
    }

    public void setRowHeight(int rowHeight) {
        this.rowHeight = rowHeight;
    }

    public int getColumWidth() {
        return columWidth;
    }

    public void setColumWidth(int columWidth) {
        this.columWidth = columWidth;
    }

    public String getSheetName() {
        return sheetName;
    }

    public void setSheetName(String sheetName) {
        this.sheetName = sheetName;
    }

    public Map<String, String> getHeaderMap() {
        return headerMap;
    }

    public void setHeaderMap(Map<String, String> headerMap) {
        this.headerMap = headerMap;
    }

    /**
     * 开始导出数据信息
     *
     */
    public void exportExport(HttpServletRequest request, HttpServletResponse response) throws IOException {
        //检查参数配置信息
        checkConfig();
        //创建工作簿
        @SuppressWarnings("resource")
        XSSFWorkbook wb = new XSSFWorkbook();
        Integer dataSize = data.size();
        Long sheetNum = dataSize / SHEET_DATA_SIZE  +  (dataSize % SHEET_DATA_SIZE == 0 ? 0L : 1L);
    	for(int num=0;num<sheetNum;num++) {
    		int fromIndex = num*SHEET_DATA_SIZE;
    		int toIndex = Math.min(fromIndex + SHEET_DATA_SIZE, data.size());
    		List<JSONObject> exportDataList = data.subList(fromIndex, toIndex);
    		
    		//创建工作表
            XSSFSheet wbSheet = wb.createSheet(this.sheetName+(num+1));
            //设置默认行宽
            wbSheet.setDefaultColumnWidth(20);

            // 标题样式（加粗，垂直居中）
            XSSFCellStyle cellStyle = wb.createCellStyle();
            cellStyle.setAlignment(HSSFCellStyle.ALIGN_CENTER);//水平居中
            cellStyle.setVerticalAlignment(HSSFCellStyle.VERTICAL_CENTER);//垂直居中
            XSSFFont fontStyle = wb.createFont();
            fontStyle.setBoldweight(HSSFFont.BOLDWEIGHT_BOLD);
            fontStyle.setBold(true);   //加粗
            fontStyle.setFontHeightInPoints((short)16);  //设置标题字体大小
            cellStyle.setFont(fontStyle);
            setBorderStyle(cellStyle); //设置边框

            //在第0行创建rows  (表标题)
            XSSFRow title = wbSheet.createRow((int) 0);
            title.setHeightInPoints(30);//行高
            XSSFCell cellValue = title.createCell(0);
            cellValue.setCellValue(this.title);
            cellValue.setCellStyle(cellStyle);
            wbSheet.addMergedRegion(new CellRangeAddress(0,0,0,(this.heardList.length-1)));


            //在第1行创建rows
            XSSFRow row = wbSheet.createRow((int) 1);
            //设置列头元素
            XSSFCell cellHead = null;
            XSSFCellStyle firstRowStyle = getCommonCellStyle(wb);
            for (int i = 0; i < heardList.length; i++) {
                cellHead = row.createCell(i);
                cellHead.setCellValue(heardList[i]);
                cellHead.setCellStyle(firstRowStyle);
            }

            //设置每格数据的样式 （字体红色）
            XSSFCellStyle cellParamStyle = wb.createCellStyle();
            XSSFFont ParamFontStyle = wb.createFont();
            cellParamStyle.setAlignment(HSSFCellStyle.ALIGN_CENTER);
            cellParamStyle.setVerticalAlignment(HSSFCellStyle.VERTICAL_CENTER);
            ParamFontStyle.setColor(HSSFColor.DARK_RED.index);   //设置字体颜色 (红色)
            ParamFontStyle.setFontHeightInPoints((short) this.fontSize);
            cellParamStyle.setFont(ParamFontStyle);
            //设置每格数据的样式2（字体蓝色）
            XSSFCellStyle cellParamStyle2 = wb.createCellStyle();
            cellParamStyle2.setAlignment(HSSFCellStyle.ALIGN_CENTER);
            cellParamStyle2.setVerticalAlignment(HSSFCellStyle.VERTICAL_CENTER);
            XSSFFont ParamFontStyle2 = wb.createFont();
            ParamFontStyle2.setColor(HSSFColor.BLUE.index);   //设置字体颜色 (蓝色)
            ParamFontStyle2.setFontHeightInPoints((short) this.fontSize);
            cellParamStyle2.setFont(ParamFontStyle2);
            //开始写入实体数据信息
            int a = 2;
            for (int i = 0; i < exportDataList.size(); i++) {
                XSSFRow roww = wbSheet.createRow((int) a);
                JSONObject map = exportDataList.get(i);
                XSSFCell cell = null;
                for (int j = 0; j < heardKey.length; j++) {
                    cell = roww.createCell(j);
                    cell.setCellStyle(getCommonCellStyle(wb));
                    cell.getCellStyle().setAlignment(getCellAlignType(headerMap.get(heardKey[j] + "AlignType"))); //重新设置对齐方式
                    Object valueObject = map.get(heardKey[j]);
                    String value = null;
                    if (valueObject == null) {
                        valueObject = "";
                    }

                    if (valueObject instanceof String) {
                        //取出的数据是字符串直接赋值
                        value = (String) map.get(heardKey[j]);
                    } else if (valueObject instanceof Integer) {
                        //取出的数据是Integer
                        value = String.valueOf(((Integer) (valueObject)).floatValue());
                    } else if (valueObject instanceof Number) {
                        value = new BigDecimal(valueObject.toString()).toPlainString();
                    } else {
                        value = valueObject.toString();
                    }
                    value = formatField(value, fieldFormat.get(j));
                    //设置单个单元格的字体颜色
                    if(heardKey[j].equals("ddNum") || heardKey[j].equals("sjNum")){
                        if((Long)map.get("ddNum")!=null){
                            if((Long)map.get("sjNum")==null){
                                cell.setCellStyle(cellParamStyle);
                            } else if((Long) map.get("ddNum") != (Long) map.get("sjNum")){
                                if ((Long) map.get("ddNum") > (Long) map.get("sjNum")) {
                                    cell.setCellStyle(cellParamStyle);
                                }
                                if ((Long) map.get("ddNum") < (Long) map.get("sjNum")) {
                                    cell.setCellStyle(cellParamStyle2);
                                }
                            }else {
                                cell.setCellStyle(getCommonCellStyle(wb));
                            }
                        }
                    }
                    if (valueObject instanceof Number) {
                        if(StringUtils.isNotEmpty(value)){
                            XSSFCellStyle style = getCommonCellStyle(wb);
                            if (valueObject instanceof Integer) {
                                cell.setCellValue((Integer)valueObject);
                                style.setDataFormat(wb.createDataFormat().getFormat("0"));
                            }else {
                                String valueStr = value.replaceAll(",", ""); // 删除逗号
                                if(StringUtils.isEmpty(value)){
                                    valueStr = "0.00";
                                }
                                cell.setCellValue(new Double(valueStr));
                                style.setDataFormat(wb.createDataFormat().getFormat("0.00"));
                            }
                            if(StringUtils.isNotEmpty(fieldFormat.get(j))){
                                switch (fieldFormat.get(j)) {
                                    case "twoDecimalNumbers":
                                    case "mnyFormat":
                                        style.setDataFormat(wb.createDataFormat().getFormat("0.00"));
                                        break;
                                    case "integer":
                                        style.setDataFormat(wb.createDataFormat().getFormat("0"));
                                        break;
                                    default:
                                }
                            }
                            cell.setCellStyle(style);
                        }
                    }else {
                        cell.setCellValue(Strings.isNullOrEmpty(value) ? "" : value);
                    }
                }
                a++;
            }
    	}
        //导出数据
        try {
            //设置Http响应头告诉浏览器下载这个附件
            response.setHeader("Content-Disposition", "attachment;Filename=" + System.currentTimeMillis() + ".xlsx"); 
            OutputStream outputStream = response.getOutputStream();
            wb.write(outputStream);
            outputStream.close();
        } catch (Exception ex) {
            ex.printStackTrace();
            throw new IOException("导出Excel出现严重异常，异常信息：" + ex.getMessage());
        }
    }

    private void setBorderStyle(XSSFCellStyle cellStyle) {
        cellStyle.setBorderBottom(XSSFCellStyle.BORDER_THIN); //下边框
        cellStyle.setBorderLeft(XSSFCellStyle.BORDER_THIN);//左边框
        cellStyle.setBorderTop(XSSFCellStyle.BORDER_THIN);//上边框
        cellStyle.setBorderRight(XSSFCellStyle.BORDER_THIN);//右边框
    }

    private String formatField(String value, String format) {
        String result = null;

        if(StringUtils.isBlank(value) || StringUtils.isBlank(format)) {
            return value;
        }
        try {
            switch (format) {
                case "twoDecimalNumbers":
                    result = new BigDecimal(value).setScale(2, BigDecimal.ROUND_HALF_UP).toString();
                    break;
                case "integer":
                    result = new BigDecimal(value).setScale(0, BigDecimal.ROUND_HALF_UP).toString();
                    break;
                case "mnyFormat":
                    result = decimalFormat.format( new BigDecimal(value).setScale(6, BigDecimal.ROUND_HALF_UP));
                    break;
                case "yyyy-MM-dd":
                    result = dateFormat.format(dateFormat.parse(value));
                    break;
                case "yyyy-MM-dd HH:mm:ss":
                    result = dateTimeFormat.format(dateTimeFormat.parse(value));
                    break;
                default:
            }
        } catch (Exception e) {
            logger.error("依据模式[{}],格式化格式化[{}]异常：", format, value, e);
            return value;
        }
        return result;
    }


    /**
     * 检查数据配置问题
     *
     * @throws IOException 抛出数据异常类
     */
    protected void checkConfig() throws IOException {
        if (heardKey == null || heardList.length == 0) {
            throw new IOException("列名数组不能为空或者为NULL");
        }

        if (fontSize < 0 || rowHeight < 0 || columWidth < 0) {
            throw new IOException("字体、宽度或者高度不能为负值");
        }

        if (Strings.isNullOrEmpty(sheetName)) {
            throw new IOException("工作表表名不能为NULL");
        }
    }

    private XSSFCellStyle getCommonCellStyle(XSSFWorkbook wb) {
        //设置表头样式，表头居中
        XSSFCellStyle style = wb.createCellStyle();
        //设置单元格样式
        style.setAlignment(HSSFCellStyle.ALIGN_CENTER);
        style.setVerticalAlignment(HSSFCellStyle.VERTICAL_CENTER);
        //设置字体
        XSSFFont font = wb.createFont();
        font.setFontHeightInPoints((short) this.fontSize);
        style.setFont(font);
        setBorderStyle(style); //设置边框

        return style;
    }

    private short getCellAlignType(String columnAlignType) {
        short alignType = HSSFCellStyle.ALIGN_CENTER;
        switch (columnAlignType) {
            case "left":
                alignType = HSSFCellStyle.ALIGN_LEFT;
                break;
            case "center":
                alignType = HSSFCellStyle.ALIGN_CENTER;
                break;
            case "right":
                alignType = HSSFCellStyle.ALIGN_RIGHT;
                break;
        }
        return alignType;
    }
}
